@@ -1,7 +1,7 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 #
 # This file is part of GNU Mes.
 #
@@ -20,32 +20,64 @@
 
 set -e
 
-VERSION=0.19
+VERSION=0.20
 srcdir=${srcdir-$(dirname $0)}
 . ${srcdest}build-aux/trace.sh
 
-# parse --mes
+# parse --with-system-libc
 cmdline=$(echo " $@")
-p=${cmdline/ --mes/}
-if [ "$p" != "$cmdline" ]; then
-    mes_p=${mes_p-1}
+p=${cmdline/ --with-system-libc/}
+if test "$p" != "$cmdline"; then
+    mes_libc=${mes_libc-system}
+else
+    mes_libc=mes
+fi
+
+# parse --with-courage
+cmdline=$(echo " $@")
+p=${cmdline/ --with-courage/}
+if test "$p" != "$cmdline"; then
+    courageous=true
+else
+    courageous=false
 fi
 
 # parse --prefix=PREFIX
 p=${cmdline/ --prefix=/ -prefix=}
-if [ "$p" != "$cmdline" ]; then
+if test "$p" != "$cmdline"; then
     p=${p##* -prefix=}
     p=${p% *}
     p=${p% -*}
     prefix=${p-/usr/local}
-
 else
     prefix=${prefix-/usr/local}
 fi
 
+# parse --build=BUILD
+p=${cmdline/ --build=/ -build=}
+if [ "$p" != "$cmdline" ]; then
+    p=${p##* -build=}
+    p=${p% *}
+    p=${p% -*}
+    build=${p-$build}
+else
+    build=$build
+fi
+
+# parse --host=HOST
+p=${cmdline/ --host=/ -host=}
+if [ "$p" != "$cmdline" ]; then
+    p=${p##* -host=}
+    p=${p% *}
+    p=${p% -*}
+    host=${p-$build}
+elif test -n "$build"; then
+    host=${host-$build}
+fi
+
 # parse --program-prefix=
 p=${cmdline/ --program-prefix=/ -program-prefix=}
-if [ "$p" != "$cmdline" ]; then
+if test "$p" != "$cmdline"; then
     p=${p##* -program-prefix=}
     p=${p% *}
     p=${p% -*}
@@ -56,10 +88,11 @@ AR=${AR-$(command -v ar)} || true
 BASH=${BASH-$(command -v bash)}
 BLOOD_ELF=${BLOOD_ELF-$(command -v blood-elf)}
 CC=${CC-$(command -v gcc)} || true
+DIFF=${DIFF-$(command -v diff || echo $PWD/pre-inst-env diff.scm)}
 GUILD=${GUILD-$(command -v guild)} || true
 GUILE_TOOLS=${GUILE_TOOLS-$(command -v guile-tools)} || true
-if [ ! "$GUILD" ]; then
-    if [ "$GUILE_TOOLS" ]; then
+if test ! "$GUILD"; then
+    if test "$GUILE_TOOLS"; then
         GUILD=$GUILE_TOOLS
     else
         GUILD=true
@@ -71,9 +104,11 @@ M1=${M1-$(command -v M1)}
 MES_FOR_BUILD=${MES_FOR_BUILD-$(command -v mes || command -v guile || echo mes)}
 GIT=${GIT-$(command -v git)} || true
 PERL=${PERL-$(command -v perl)} || true
+SHELL=${BASH-$SHELL}
+
 MES_SEED=${MES_SEED-../mes-seed}
 
-if [ "$srcdir" = . ]; then
+if test "$srcdir" = .; then
     top_builddir=.
 else
     srcdest=${srcdest}
@@ -82,7 +117,7 @@ fi
 abs_top_srcdir=${abs_top_srcdir-$(cd ${srcdir} && pwd)}
 abs_top_builddir=$PWD
 
-if [ -z "$GUILE" -o "$GUILE" = true ]; then
+if test -z "$GUILE" -o "$GUILE" = true; then
     GUILE_EFFECTIVE_VERSION=${GUILE_EFFECTIVE_VERSION-2.2}
 else
     GUILE_EFFECTIVE_VERSION=${GUILE_EFFECTIVE_VERSION-$(guile -c '(display (effective-version))')}
@@ -91,27 +126,29 @@ bindir=$(eval echo ${bindir-$prefix/bin})
 datadir=$(eval echo ${datadir-$prefix/share})
 docdir=$(eval echo ${docdir-$datadir/doc/mes-$VERSION})
 infodir=$(eval echo ${infodir-$datadir/info})
+includedir=$(eval echo ${libdir-$prefix/include})
 libdir=$(eval echo ${libdir-$prefix/lib})
+pkgdatadir=$(eval echo ${pkgdatadir-$datadir/mes})
 mandir=$(eval echo ${mandir-$datadir/man})
-moduledir=$(eval echo ${moduledir-$datadir/mes/module})
-moduledir_="$moduledir/"
 guile_site_dir=$(eval echo ${guile_site_dir-$prefix/share/guile/site/$GUILE_EFFECTIVE_VERSION})
 guile_site_ccache_dir=$(eval echo ${guile_site_ccache_dir-$prefix/lib/guile/$GUILE_EFFECTIVE_VERSION/site-ccache})
 
 subst () {
+    echo "creating $2"
     sed \
     -e s,"@PACKAGE@,$PACKAGE,"\
+    -e s,"@PACKAGE_NAME@,$PACKAGE_NAME,"\
+    -e s,"@PACKAGE_BUGREPORT@,$PACKAGE_BUGREPORT,"\
     -e s,"@VERSION@,$VERSION,"\
-    -e s,"@arch@,$arch,"\
     -e s,"@build@,$build,"\
     -e s,"@host@,$host,"\
     -e s,"@compiler@,$compiler,"\
-    -e s,"@gcc_p@,$gcc_p,"\
-    -e s,"@mes_p@,$mes_p,"\
-    -e s,"@mesc_p@,$mesc_p,"\
-    -e s,"@tcc_p@,$tcc_p,"\
-    -e s,"@mes_arch@,$mes_arch,"\
-    -e s,"@posix_p@,$posix_p,"\
+    -e s,"@courageous@,$courageous,"\
+    -e s,"@mes_bits@,$mes_bits,"\
+    -e s,"@mes_kernel@,$mes_kernel,"\
+    -e s,"@mes_cpu@,$mes_cpu,"\
+    -e s,"@mes_libc@,$mes_libc,"\
+    -e s,"@mes_system@,$mes_system,"\
     -e s,"@abs_top_srcdir@,$abs_top_srcdir,"\
     -e s,"@abs_top_builddir@,$abs_top_builddir,"\
     -e s,"@top_builddir@,$top_builddir,"\
@@ -125,9 +162,10 @@ subst () {
     -e s,"@guile_site_dir@,$guile_site_dir,"\
     -e s,"@guile_site_ccache_dir@,$guile_site_ccache_dir,"\
     -e s,"@infodir@,$infodir,"\
+    -e s,"@includedir@,$includedir,"\
     -e s,"@libdir@,$libdir,"\
     -e s,"@mandir@,$mandir,"\
-    -e s,"@moduledir@,$moduledir,"\
+    -e s,"@pkgdatadir@,$pkgdatadir,"\
     -e s,"@sysconfdir@,$sysconfdir,"\
     -e s,"@GUILE_EFFECTIVE_VERSION@,$GUILE_EFFECTIVE_VERSION,"\
     -e s,"@V@,$V,"\
@@ -135,6 +173,7 @@ subst () {
     -e s,"@BASH@,$BASH,"\
     -e s,"@BLOOD_ELF@,$BLOOD_ELF,"\
     -e s,"@CC@,$CC,"\
+    -e s,"@DIFF@,$DIFF,"\
     -e s,"@GIT@,$GIT,"\
     -e s,"@GUILD@,$GUILD,"\
     -e s,"@GUILE@,$GUILE,"\
@@ -148,72 +187,100 @@ subst () {
     -e s,"@MES_SEED@,$MES_SEED,"\
     -e s,"@MES_SEED@,$MES_SEED,"\
     -e s,"@SHELL@,$SHELL,"\
-    -e s,"mes/module/,$moduledir/,"\
     $1 > $2
 }
 
-subst ${srcdest}build-aux/pre-inst-env.in pre-inst-env
-chmod +x pre-inst-env
-subst ${srcdest}scripts/mescc.in scripts/mescc
-chmod +x scripts/mescc
-subst ${srcdest}scripts/mescc.scm.in scripts/mescc.scm
-chmod +x scripts/mescc.scm
-
-host=${host-$($CC -dumpmachine 2>/dev/null || echo x86)}
-if [ -z "$host" ]; then
-    arch=${arch-$(get_machine || uname -m)}
+host=${host-$($CC -dumpmachine 2>/dev/null)}
+if test -z "$host$host_type"; then
+    mes_cpu=${arch-$(get_machine || uname -m)}
 else
-    arch=${host%%-*}
+    mes_cpu=${host%%-*}
 fi
-if [ "$arch" = i386\
-             -o "$arch" = i486\
-             -o "$arch" = i586\
-             -o "$arch" = i686\
-   ]; then
-    arch=x86
+if test "$mes_cpu" = i386\
+        || test "$mes_cpu" = i486\
+        || test "$mes_cpu" = i586\
+        || test "$mes_cpu" = i686; then
+    mes_cpu=x86
+fi
+if test "$mes_cpu" = armv4\
+        || test "$arch" = armv7l; then
+    mes_cpu=arm
+fi
+if test "$mes_cpu" = amd64; then
+    mes_cpu=x86_64
 fi
 
+case "$host" in
+    *linux-gnu|*linux)
+        mes_kernel=linux;;
+    *gnu)
+        mes_kernel=gnu;;
+    *)
+        mes_kernel=linux;;
+esac
+
+case "$mes_cpu" in
+    x86_64)
+        mes_bits=64;;
+    *)
+        mes_bits=32;;
+esac
 #
 if $CC --version | grep gcc; then #2>/dev/null; then
-    gcc_p=1
     compiler=gcc
 elif $CC --version | grep tcc; then #2>/dev/null; then
-    tcc_p=1
-    compiler=tcc
+    compiler=gcc
 else
-    mes_p=1
-    mesc_p=1
     compiler=mescc
 fi
 
-mes_arch=$arch
-if [ "$mes_p" -o "$mesc_p" ]; then
-    mes_arch=$arch-mes
-fi
+mes_system=$mes_cpu-$mes_kernel-mes
 
-if [ ! "$mesc_p" ]; then
-    mes_arch=$mes_arch-$compiler
-fi
-if [ ! "$mesc_p" -a ! "$mes_p" ]; then
-    posix_p=1
-fi
-
-subst ${srcdest}mes/module/mes/boot-0.scm.in mes/module/mes/boot-0.scm
 subst ${srcdest}build-aux/GNUmakefile.in GNUmakefile
-subst ${srcdest}build-aux/config.status.in config.status
-subst ${srcdest}build-aux/build.sh.in build.sh
-chmod +x build.sh
+subst ${srcdest}build-aux/config.sh.in config.sh
 subst ${srcdest}build-aux/bootstrap.sh.in bootstrap.sh
 chmod +x bootstrap.sh
+subst ${srcdest}build-aux/build.sh.in build.sh
+chmod +x build.sh
 subst ${srcdest}build-aux/check.sh.in check.sh
 chmod +x check.sh
 subst ${srcdest}build-aux/install.sh.in install.sh
 chmod +x install.sh
+subst ${srcdest}build-aux/pre-inst-env.in pre-inst-env
+chmod +x pre-inst-env
+subst ${srcdest}scripts/mesar.in scripts/mesar
+chmod +x scripts/mesar
+subst ${srcdest}scripts/mescc.scm.in scripts/mescc.scm
+chmod +x scripts/mescc.scm
+subst ${srcdest}scripts/mescc.in scripts/mescc
+chmod +x scripts/mescc
 subst ${srcdest}build-aux/uninstall.sh.in uninstall.sh
 chmod +x uninstall.sh
 
+mkdir -p include/mes
+rm -f include/mes/config.h
+if test $mes_libc = system; then
+    cat >> include/mes/config.h <<EOF
+#define SYSTEM_LIBC 1
+EOF
+else
+    cat >> include/mes/config.h <<EOF
+#undef SYSTEM_LIBC
+EOF
+fi
+cat >> include/mes/config.h <<EOF
+#define MES_VERSION "$VERSION"
+#define MES_PKGDATADIR "$pkgdatadir"
+EOF
+
 cat <<EOF
-GNU Mes is configured for $mes_arch
+GNU Mes is configured for
+   compiler: $compiler
+   cpu:      $mes_cpu
+   bits:     $mes_bits
+   libc:     $mes_libc
+   kernel:   $mes_kernel
+   system:   $mes_system
 
 Run:
   ./build.sh      to build mes
