@@ -20,20 +20,31 @@
 #ifndef __MES_CTYPE_H
 #define __MES_CTYPE_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_CTYPE_H
 #include_next <ctype.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 #include <endian.h>
+
+int isalnum (int c);
 int isalpha (int c);
 int isascii (int c);
+int iscntrl (int c);
 int isdigit (int c);
-int isxdigit (int c);
+int islower (int c);
+int isnumber (int c, int base);
+int isprint (int c);
+int ispunct (int c);
 int isspace (int c);
-#endif // ! WITH_GLIBC
+int isupper (int c);
+int isxdigit (int c);
+int tolower (int c);
+int toupper (int c);
+
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_CTYPE_H
