@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -20,10 +20,10 @@
 #ifndef __MES_STDARG_H
 #define __MES_STDARG_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #undef __MES_STDARG_H
 #include_next <stdarg.h>
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #include <sys/types.h>
 
@@ -31,18 +31,19 @@
 #define __FOO_VARARGS 1
 #endif
 
-typedef long va_list;
+typedef char *va_list;
 #define va_start(ap, last) (void)((ap) = (char*)(&(last) + 1))
 #define va_arg(ap, type) (type)(((long*)((ap) = ((ap) + sizeof (void*))))[-1])
 #define va_end(ap) (void)((ap) = 0)
 #define va_copy(dest, src) dest = src
 
-int vfprintf (FILE *stream, char const *template, va_list ap);
-int vprintf (char const* format, va_list ap);
+int vexec (char const *file_name, va_list ap);
+int vfprintf (FILE * stream, char const *template, va_list ap);
+int vprintf (char const *format, va_list ap);
 int vsprintf (char *str, char const *format, va_list ap);
 int vsnprintf (char *str, size_t size, char const *format, va_list ap);
 int vsscanf (char const *s, char const *template, va_list ap);
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_STDARG_H
