@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -20,28 +20,34 @@
 #ifndef __MES_STDLIB_H
 #define __MES_STDLIB_H 1
 
-#if WITH_GLIBC
+#ifndef __MES_COMPARISON_FN_T
+#define __MES_COMPARISON_FN_T
+typedef int (*comparison_fn_t) (void const *, void const *);
+#endif
+
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_STDLIB_H
 #include_next <stdlib.h>
-#else  // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #include <sys/types.h>
 #include <alloca.h>
 
+double atof (char const *s);
 int atoi (char const *s);
 int atexit (void (*function) (void));
-void * calloc (size_t nmemb, size_t size);
+void *calloc (size_t nmemb, size_t size);
 void _exit (int status);
 void exit (int status);
 void free (void *ptr);
-char* getenv (char const* s);
-int setenv (char const* s, char const* v, int overwrite_p);
+char *getenv (char const *s);
+int setenv (char const *s, char const *v, int overwrite_p);
 void unsetenv (char const *name);
 void *malloc (size_t);
-void qsort (void *base, size_t nmemb, size_t size, int (*compar)(void const *, void const *));
+void qsort (void *base, size_t nmemb, size_t size, int (*compar) (void const *, void const *));
 int rand (void);
 void *realloc (void *p, size_t size);
 double strtod (char const *string, char **tailptr);
@@ -55,13 +61,8 @@ unsigned long long strtoull (char const *string, char **tailptr, int base);
 #define EXIT_FAILURE 1
 #define EXIT_SUCCESS 0
 
-#ifndef __MES_COMPARISON_FN_T
-#define __MES_COMPARISON_FN_T
-typedef int (*comparison_fn_t) (void const *, void const *);
-#endif
+void *bsearch (void const *key, void const *array, size_t count, size_t size, comparison_fn_t compare);
 
-void * bsearch (void const *key, void const *array, size_t count, size_t size, comparison_fn_t compare);
-
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_STDLIB_H
