@@ -20,10 +20,10 @@
 #ifndef __MES_SYS_TYPES_H
 #define __MES_SYS_TYPES_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #undef __MES_SYS_TYPES_H
 #include_next <sys/types.h>
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #include <endian.h>
 
@@ -48,25 +48,25 @@ typedef long clock_t;
 #ifndef __MES_DEV_T
 #define __MES_DEV_T
 #undef dev_t
-typedef int dev_t;
+typedef long dev_t;
 #endif
 
 #if !defined (__MES_FILE_T) && ! defined (_FILE_T)
 #define __MES_FILE_T
 #define _FILE_T
-typedef int FILE;
+typedef long FILE;
 #endif
 
 #ifndef __MES_GID_T
 #define __MES_GID_T
 #undef gid_t
-typedef int gid_t;
+typedef unsigned gid_t;
 #endif
 
 #ifndef __MES_INO_T
 #define __MES_INO_T
 #undef ino_t
-typedef unsigned ino_t;
+typedef unsigned long ino_t;
 #endif
 
 #ifndef __MES_INO64_T
@@ -75,10 +75,13 @@ typedef unsigned ino_t;
 typedef unsigned long long ino64_t;
 #endif
 
-#ifndef __MES_INTPTR_T
+#if !defined (__MES_INTPTR_T) && !defined (__intptr_t_defined)
 #define __MES_INTPTR_T
+#define __intptr_t_defined
 #undef intptr_t
 typedef long intptr_t;
+#undef uintptr_t
+typedef unsigned long uintptr_t;
 #endif
 
 #ifndef __MES_OFF_T
@@ -111,7 +114,7 @@ typedef long ptrdiff_t;
 #ifndef __MES_SIGVAL_T
 #define __MES_SIGVAL_T
 #undef clock_t
-typedef int sigval_t;
+typedef long sigval_t;
 #endif
 
 #ifndef __SIZE_T
@@ -132,9 +135,9 @@ typedef long ssize_t;
 #ifndef __MES_UID_T
 #define __MES_UID_T
 #undef uid_t
-typedef int uid_t;
+typedef unsigned uid_t;
 #endif
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_SYS_TYPES_H
