@@ -20,10 +20,10 @@
 #ifndef __MES_TIME_H
 #define __MES_TIME_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #undef __MES_TIME_H
 #include_next <time.h>
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #ifndef __MES_TIME_T
 #define __MES_TIME_T 1
@@ -31,7 +31,8 @@ typedef long int clockid_t;
 typedef long int time_t;
 #endif
 
-struct tm {
+struct tm
+{
   int tm_sec;
   int tm_min;
   int tm_hour;
@@ -58,9 +59,9 @@ struct timespec
 int clock_gettime (clockid_t clk_id, struct timespec *tp);
 struct tm *localtime (time_t const *timep);
 struct tm *gmtime (time_t const *time);
+int nanosleep (struct timespec const *requested_time, struct timespec const *remaining);
+time_t time (time_t * tloc);
 
-time_t time (time_t *tloc);
-
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_TIME_H
