@@ -20,14 +20,14 @@
 #ifndef __MES_UNISTD_H
 #define __MES_UNISTD_H 1
 
-#if WITH_GLIBC
+#if SYSTEM_LIBC
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #undef __MES_UNISTD_H
 #include_next <unistd.h>
 
-#else // ! WITH_GLIBC
+#else // ! SYSTEM_LIBC
 
 #if defined (BOOTSTRAP_WITH_POSIX)
 #define _POSIX_VERSION 199009L
@@ -65,6 +65,7 @@ int execl (char const *file_name, char const *arg, ...);
 int execve (char const *file, char *const argv[], char *const env[]);
 int execvp (char const *file, char *const argv[]);
 int fork (void);
+int fsync (int filedes);
 char *getcwd (char *buf, size_t size);
 uid_t getuid (void);
 gid_t getgid (void);
@@ -72,20 +73,22 @@ int setgid (gid_t newgid);
 int setuid (uid_t newuid);
 uid_t geteuid (void);
 gid_t getegid (void);
+pid_t getpid (void);
+pid_t getppid (void);
 int isatty (int fd);
 int link (char const *oldname, char const *newname);
 off_t lseek (int fd, off_t offset, int whence);
 ssize_t read (int fd, void *buffer, size_t size);
 #if __SBRK_CHAR_PTRDIFF
 /* xmalloc in binutils <= 2.10.1 uses this old prototype */
-char * sbrk (ptrdiff_t delta);
+char *sbrk (ptrdiff_t delta);
 #else
-void * sbrk (intptr_t delta);
+void *sbrk (intptr_t delta);
 #endif
 int unlink (char const *file_name);
 ssize_t write (int filedes, void const *buffer, size_t size);
 pid_t getpid (void);
 
-#endif // ! WITH_GLIBC
+#endif // ! SYSTEM_LIBC
 
 #endif // __MES_UNISTD_H
