@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,31 +18,22 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <assert.h>
 
 int
 fdungetc (int c, int fd)
 {
+  __ungetc_init ();
   if (c == -1)
     return c;
-  if (_ungetc_pos == -1)
-    _ungetc_fd = fd;
-  else if (_ungetc_fd != fd)
+  else if (__ungetc_p (fd))
     {
-      eputs (" ***MES LIB C*** fdungetc ungetc conflict unget-fd=");
-      eputs (itoa (_ungetc_fd));
-      eputs (", fdungetc-fd=");
+      eputs (" ***MES C LIB*** fdungetc ungetc buffer overflow fd=");
       eputs (itoa (fd));
       eputs ("\n");
-      exit (1);
+      assert (0);
     }
-  _ungetc_pos++;
-  _ungetc_buf[_ungetc_pos] = c;
+  __ungetc_set (fd, c);
   return c;
 }
-
-int
-_fdungetc_p (int fd)
-{
-  return _ungetc_pos > -1;
-}
