@@ -18,7 +18,8 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <stdarg.h>
 #include <unistd.h>
 
 int
@@ -26,23 +27,29 @@ execl (char const *file_name, char const *arg, ...)
 {
   if (__mes_debug () > 2)
     {
-      eputs ("execl "); eputs (file_name); eputs ("\n");
+      eputs ("execl ");
+      eputs (file_name);
+      eputs ("\n");
     }
-  char *argv[1000];           // POSIX minimum 4096
+  char *argv[1000];             // POSIX minimum 4096
   int i = 0;
 
   va_list ap;
   va_start (ap, arg);
 
-  argv[i++] = file_name;
+  argv[i++] = (char *)file_name;
   arg = va_arg (ap, char const *);
   while (arg)
     {
       argv[i++] = arg;
-      arg = va_arg (ap, char const *);
+      arg = va_arg (ap, char *);
       if (__mes_debug () > 2)
         {
-          eputs ("arg["); eputs (itoa (i)); eputs ("]: "); eputs (argv[i-1]); eputs ("\n");
+          eputs ("arg[");
+          eputs (itoa (i));
+          eputs ("]: ");
+          eputs (argv[i - 1]);
+          eputs ("\n");
         }
     }
   argv[i] = 0;
