@@ -18,14 +18,15 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
 
 int
-vfprintf (FILE* f, char const* format, va_list ap)
+vfprintf (FILE * f, char const *format, va_list ap)
 {
-  int fd = (long)f;
+  int fd = (long) f;
   char const *p = format;
   int count = 0;
   while (*p)
@@ -106,9 +107,7 @@ vfprintf (FILE* f, char const* format, va_list ap)
           case 'X':
             {
               long d = va_arg (ap, long);
-              int base = c == 'o' ? 8
-                : c == 'x' || c == 'X' ? 16
-                : 10;
+              int base = c == 'o' ? 8 : c == 'x' || c == 'X' ? 16 : 10;
               char const *s = ntoab (d, base, c != 'u' && c != 'x' && c != 'X');
               if (c == 'X')
                 strupr (s);
