@@ -18,13 +18,17 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 int
 vsscanf (char const *s, char const *template, va_list ap)
 {
-  char const *p = s;
+  char *p = (char *) s;
   char const *t = template;
   int count = 0;
   while (*t && *p)
@@ -48,7 +52,7 @@ vsscanf (char const *s, char const *template, va_list ap)
             }
           case 'c':
             {
-              char *c = va_arg (ap, char*);
+              char *c = va_arg (ap, char *);
               *c = *p++;
               count++;
               break;
@@ -57,8 +61,8 @@ vsscanf (char const *s, char const *template, va_list ap)
           case 'i':
           case 'u':
             {
-              int *d = va_arg (ap, int*);
-              *d = abtol (&p, 10);
+              int *d = va_arg (ap, int *);
+              *d = abtol ((char const **)&p, 10);
               count++;
               break;
             }
