@@ -24,8 +24,7 @@
 typedef char wchar_t[];
 
 size_t
-mbstowcs (wchar_t *wstring, char const *string,
-          size_t size)
+mbstowcs (wchar_t * wstring, char const *string, size_t size)
 {
   static int stub = 0;
   if (__mes_debug () && !stub)
