@@ -18,8 +18,9 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
-#include <stdio.h>
+#include <mes/lib.h>
+#include <errno.h>
+#include <unistd.h>
 
 int
 fscanf (FILE *stream, char const *template, ...)
