@@ -18,11 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <errno.h>
 #include <pwd.h>
 
 struct passwd *
-getpwuid ()
+getpwuid (uid_t uid)
 {
   static int stub = 0;
   if (__mes_debug () && !stub)
