@@ -18,11 +18,11 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
 #include <string.h>
 
 int
-strcmp (char const* a, char const* b)
+strcmp (char const *a, char const *b)
 {
   while (*a && *b && *a == *b)
     {
