@@ -18,22 +18,24 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "mes/lib.h"
+#include "mes/mes.h"
+
+#include <assert.h>
 #include <fcntl.h>
 #include <limits.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/stat.h>
+#include <time.h>
 #include <sys/time.h>
 #include <sys/wait.h>
-#include <time.h>
 #include <unistd.h>
 
-int readchar ();
-int unreadchar ();
-
 int
 peekchar ()
 {
-  if (g_stdin >= 0)
+  if (__stdin >= 0)
     {
       int c = readchar ();
       unreadchar (c);
@@ -51,8 +53,8 @@ peekchar ()
 int
 readchar ()
 {
-  if (g_stdin >= 0)
-    return fdgetc (g_stdin);
+  if (__stdin >= 0)
+    return fdgetc (__stdin);
   SCM port = current_input_port ();
   SCM string = STRING (port);
   size_t length = LENGTH (string);
@@ -60,21 +62,21 @@ readchar ()
     return -1;
   char const *p = CSTRING (string);
   int c = *p++;
-  STRING (port) = make_string (p, length-1);
+  STRING (port) = make_string (p, length - 1);
   return c;
 }
 
 int
 unreadchar (int c)
 {
-  if (g_stdin >= 0)
-    return fdungetc (c, g_stdin);
+  if (__stdin >= 0)
+    return fdungetc (c, __stdin);
   SCM port = current_input_port ();
   SCM string = STRING (port);
   size_t length = LENGTH (string);
   char *p = CSTRING (string);
   p--;
-  string = make_string (p, length+1);
+  string = make_string (p, length + 1);
   p = CSTRING (string);
   p[0] = c;
   STRING (port) = string;
@@ -107,13 +109,13 @@ peek_char ()
 }
 
 SCM
-read_char (SCM port) ///((arity . n))
+read_char (SCM port)            ///((arity . n))
 {
-  int fd = g_stdin;
+  int fd = __stdin;
   if (TYPE (port) == TPAIR && TYPE (car (port)) == TNUMBER)
-    g_stdin = VALUE (CAR (port));
+    __stdin = VALUE (CAR (port));
   SCM c = MAKE_CHAR (readchar ());
-  g_stdin = fd;
+  __stdin = fd;
   return c;
 }
 
@@ -125,24 +127,24 @@ unread_char (SCM i)
 }
 
 SCM
-write_char (SCM i) ///((arity . n))
+write_char (SCM i)              ///((arity . n))
 {
   write_byte (i);
   return i;
 }
 
 SCM
-write_byte (SCM x) ///((arity . n))
+write_byte (SCM x)              ///((arity . n))
 {
   SCM c = car (x);
   SCM p = cdr (x);
-  int fd = g_stdout;
+  int fd = __stdout;
   if (TYPE (p) == TPAIR && TYPE (car (p)) == TNUMBER && VALUE (CAR (p)) != 1)
     fd = VALUE (CAR (p));
   if (TYPE (p) == TPAIR && TYPE (car (p)) == TNUMBER && VALUE (CAR (p)) == 2)
-    fd = g_stderr;
+    fd = __stderr;
   char cc = VALUE (c);
-  write (fd, (char*)&cc, 1);
+  write (fd, (char *) &cc, 1);
 #if !__MESC__
   assert (TYPE (c) == TNUMBER || TYPE (c) == TCHAR);
 #endif
@@ -150,7 +152,7 @@ write_byte (SCM x) ///((arity . n))
 }
 
 SCM
-getenv_ (SCM s) ///((name . "getenv"))
+getenv_ (SCM s)                 ///((name . "getenv"))
 {
   char *p;
   p = getenv (CSTRING (s));
@@ -158,7 +160,7 @@ getenv_ (SCM s) ///((name . "getenv"))
 }
 
 SCM
-setenv_ (SCM s, SCM v) ///((name . "setenv"))
+setenv_ (SCM s, SCM v)          ///((name . "setenv"))
 {
   char buf[1024];
   strcpy (buf, CSTRING (s));
@@ -175,14 +177,10 @@ access_p (SCM file_name, SCM mode)
 SCM
 current_input_port ()
 {
-  if (g_stdin >= 0)
-    return MAKE_NUMBER (g_stdin);
+  if (__stdin >= 0)
+    return MAKE_NUMBER (__stdin);
   SCM x = g_ports;
-  if (g_debug > 2)
-    {
-      eputs ("ports:"); write_error_ (g_ports); eputs ("\n");
-    }
-  while (x && PORT (CAR (x)) != g_stdin)
+  while (x && PORT (CAR (x)) != __stdin)
     x = CDR (x);
   return CAR (x);
 }
@@ -190,17 +188,13 @@ current_input_port ()
 SCM
 open_input_file (SCM file_name)
 {
-  return MAKE_NUMBER (open (CSTRING (file_name), O_RDONLY));
+  return MAKE_NUMBER (mes_open (CSTRING (file_name), O_RDONLY, 0));
 }
 
 SCM
 open_input_string (SCM string)
 {
   SCM port = MAKE_STRING_PORT (string);
-  if (g_debug > 2)
-    {
-      eputs ("new port:"); write_error_ (port); eputs ("\n");
-    }
   g_ports = cons (port, g_ports);
   return port;
 }
@@ -210,57 +204,51 @@ set_current_input_port (SCM port)
 {
   SCM prev = current_input_port ();
   if (TYPE (port) == TNUMBER)
-    g_stdin = VALUE (port) ? VALUE (port) : STDIN;
+    __stdin = VALUE (port) ? VALUE (port) : STDIN;
   else if (TYPE (port) == TPORT)
-    g_stdin = PORT (port);
+    __stdin = PORT (port);
   return prev;
 }
 
 SCM
 current_output_port ()
 {
-  return MAKE_NUMBER (g_stdout);
+  return MAKE_NUMBER (__stdout);
 }
 
 SCM
 current_error_port ()
 {
-  return MAKE_NUMBER (g_stderr);
+  return MAKE_NUMBER (__stderr);
 }
 
 SCM
-open_output_file (SCM x) ///((arity . n))
+open_output_file (SCM x)        ///((arity . n))
 {
   SCM file_name = car (x);
   x = cdr (x);
-  int mode = S_IRUSR|S_IWUSR;
+  int mode = S_IRUSR | S_IWUSR;
   if (TYPE (x) == TPAIR && TYPE (car (x)) == TNUMBER)
     mode = VALUE (car (x));
-  return MAKE_NUMBER (open (CSTRING (file_name), O_WRONLY|O_CREAT|O_TRUNC,mode));
+  return MAKE_NUMBER (mes_open (CSTRING (file_name), O_WRONLY | O_CREAT | O_TRUNC, mode));
 }
 
 SCM
 set_current_output_port (SCM port)
 {
-  g_stdout = VALUE (port) ? VALUE (port) : STDOUT;
+  __stdout = VALUE (port) ? VALUE (port) : STDOUT;
   return current_output_port ();
 }
 
 SCM
 set_current_error_port (SCM port)
 {
-  g_stderr = VALUE (port) ? VALUE (port) : STDERR;
+  __stderr = VALUE (port) ? VALUE (port) : STDERR;
   return current_error_port ();
 }
 
 SCM
-force_output (SCM p) ///((arity . n))
-{
-  return cell_unspecified;
-}
-
-SCM
-chmod_ (SCM file_name, SCM mode) ///((name . "chmod"))
+chmod_ (SCM file_name, SCM mode)        ///((name . "chmod"))
 {
   chmod (CSTRING (file_name), VALUE (mode));
   return cell_unspecified;
@@ -279,16 +267,14 @@ primitive_fork ()
 }
 
 SCM
-execl_ (SCM file_name, SCM args) ///((name . "execl"))
+execl_ (SCM file_name, SCM args)        ///((name . "execl"))
 {
   char *c_argv[1000];           // POSIX minimum 4096
   int i = 0;
 
   if (length__ (args) > 1000)
     error (cell_symbol_system_error,
-           cons (file_name,
-                 cons (MAKE_STRING0 ("too many arguments"),
-                       cons (file_name, args))));
+           cons (file_name, cons (MAKE_STRING0 ("too many arguments"), cons (file_name, args))));
   c_argv[i++] = CSTRING (file_name);
   while (args != cell_nil)
     {
@@ -297,7 +283,11 @@ execl_ (SCM file_name, SCM args) ///((name . "execl"))
       args = CDR (args);
       if (g_debug > 2)
         {
-          eputs ("arg["); eputs (itoa (i)); eputs ("]: "); eputs (c_argv[i-1]); eputs ("\n");
+          eputs ("arg[");
+          eputs (itoa (i));
+          eputs ("]: ");
+          eputs (c_argv[i - 1]);
+          eputs ("\n");
         }
     }
   c_argv[i] = 0;
@@ -322,7 +312,7 @@ waitpid_ (SCM pid, SCM options)
 
 struct timespec g_start_time;
 SCM
-init_time (SCM a) ///((internal))
+init_time (SCM a)               ///((internal))
 {
   clock_gettime (CLOCK_PROCESS_CPUTIME_ID, &g_start_time);
   a = acons (cell_symbol_internal_time_units_per_second, MAKE_NUMBER (TIME_UNITS_PER_SECOND), a);
@@ -335,7 +325,7 @@ current_time ()
 }
 
 SCM
-gettimeofday_ () ///((name . "gettimeofday"))
+gettimeofday_ ()                ///((name . "gettimeofday"))
 {
   struct timeval time;
   gettimeofday (&time, 0);
@@ -345,8 +335,7 @@ gettimeofday_ () ///((name . "gettimeofday"))
 long
 seconds_and_nanoseconds_to_long (long s, long ns)
 {
-  return s * TIME_UNITS_PER_SECOND
-    + ns / (1000000000 / TIME_UNITS_PER_SECOND);
+  return s * TIME_UNITS_PER_SECOND + ns / (1000000000 / TIME_UNITS_PER_SECOND);
 }
 
 SCM
@@ -360,20 +349,20 @@ get_internal_run_time ()
 }
 
 SCM
-getcwd_ () ///((name . "getcwd"))
+getcwd_ ()                      ///((name . "getcwd"))
 {
   char buf[PATH_MAX];
   return MAKE_STRING0 (getcwd (buf, PATH_MAX));
 }
 
 SCM
-dup_ (SCM port) ///((name . "dup"))
+dup_ (SCM port)                 ///((name . "dup"))
 {
   return MAKE_NUMBER (dup (VALUE (port)));
 }
 
 SCM
-dup2_ (SCM old, SCM new) ///((name . "dup2"))
+dup2_ (SCM old, SCM new)        ///((name . "dup2"))
 {
   dup2 (VALUE (old), VALUE (new));
   return cell_unspecified;
